==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/LocalObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalObjectReferenceBuilder extends LocalObjectReferenceFluentImpl<LocalObjectReferenceBuilder> implements VisitableBuilder<LocalObjectReference,LocalObjectReferenceBuilder>{
  public LocalObjectReferenceBuilder() {
    this(false);
  }
  public LocalObjectReferenceBuilder(Boolean validationEnabled) {
    this(new LocalObjectReference(), validationEnabled);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalObjectReference(), validationEnabled);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance) {
    this(fluent, instance, false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalObjectReferenceBuilder(LocalObjectReference instance) {
    this(instance,false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalObjectReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public LocalObjectReference build() {
    LocalObjectReference buildable = new LocalObjectReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/LocalObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalObjectReferenceBuilder extends LocalObjectReferenceFluent<LocalObjectReferenceBuilder> implements VisitableBuilder<LocalObjectReference,LocalObjectReferenceBuilder>{
  public LocalObjectReferenceBuilder() {
    this(false);
  }
  public LocalObjectReferenceBuilder(Boolean validationEnabled) {
    this(new LocalObjectReference(), validationEnabled);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalObjectReference(), validationEnabled);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance) {
    this(fluent, instance, false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LocalObjectReference());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalObjectReferenceBuilder(LocalObjectReference instance) {
    this(instance,false);
  }
  public LocalObjectReferenceBuilder(LocalObjectReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LocalObjectReference());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalObjectReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public LocalObjectReference build() {
    LocalObjectReference buildable = new LocalObjectReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
